<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Catalog\Model\ResourceModel\Category\CollectionFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Store\Model\StoreManagerInterface;
use stdClass;

class Categories
{
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var Mongo
     */
    private $mongo;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;
    /**
     * @var CollectionFactory
     */
    private $categoryCollection;

    /**
     * Menu constructor.
     * @param ResourceConnection $resourceConnection
     * @param ScopeConfigInterface $scopeConfig
     * @param Mongo $mongo
     * @param StoreManagerInterface $storeManager
     * @param CollectionFactory $categoryCollection
     */
    public function __construct(
        ResourceConnection $resourceConnection,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo,
        StoreManagerInterface $storeManager,
        CollectionFactory $categoryCollection
    ) {
        $this->resourceConnection = $resourceConnection;
        $this->scopeConfig = $scopeConfig;
        $this->mongo = $mongo;
        $this->storeManager = $storeManager;
        $this->categoryCollection = $categoryCollection;
    }

    public function exportCategories()
    {
        $collection = $this->categoryCollection->create();
        $collection->addAttributeToSelect('*');
        $collection->addAttributeToFilter('is_active', ['eq' => '1']);
        $collection->addAttributeToFilter('level', ['gteq' => 2]);

        foreach ($this->storeManager->getStores() as $key => $value) {
            $bulkData = [];

            $collection->setStore($value)->load();

            foreach ($collection as $item) {
                $category = new stdClass();

                $category->_id = $item->getData('entity_id');
                $category->parent_id = $item->getData('parent_id');
                $category->created_at = $item->getData('created_at');
                $category->updated_at = $item->getData('updated_at');
                $url = parse_url($item->getUrl());
                $category->path = $url["path"];
                $category->position = $item->getData('position');
                $category->level = $item->getData('level');
                $category->children_count = $item->getData('children_count');
                $category->name = $item->getData('name');
                $category->description = $item->getData('description');
                $category->meta_keywords = $item->getData('meta_keywords');
                $category->meta_description = $item->getData('meta_description');
                $category->meta_title = $item->getData('meta_title');
                $category->image = ($item->getData('image')) ? '/catalog/category/' . $item->getData('image') : null;
                $category->position = $item->getData('position');
                $childrenCategories = $item->getChildren();

                if ($childrenCategories) {
                    $category->childs = explode(',', $childrenCategories);
                }
                $bulkData[] = $category;
            }

            try {
                $this->mongo->update(
                    '_id',
                    $bulkData,
                    "categories_" . $value->getData('code'),
                    true,
                    $this->scopeConfig->getValue('mongo/general/mongo_general_database')
                );

                $this->mongo->ensureIndex(["parent_id"], "categories_" . $value->getData('code'));
            } catch (MongoDB\Driver\Exception\Exception $e) {
                echo $e->getMessage();
            }
        }
    }
}
