<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;
use MongoDB\Driver\Exception\Exception;
use stdClass;

class Config
{
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var Mongo
     */
    private $mongo;

    public function __construct(
        StoreManagerInterface $storeManager,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo
    ) {
        $this->storeManager = $storeManager;
        $this->scopeConfig = $scopeConfig;
        $this->mongo = $mongo;
    }

    public function exportConfig()
    {
        $stores = $this->storeManager->getStores();
        $bulkData = [];
        foreach ($stores as $value) {
            $bulkData[] = $this->getConfig($value);
        }

        $bulkData[] = $this->getConfig('default');

        try {
            $this->mongo->update(
                '_id',
                $bulkData,
                'configs',
                true,
                $this->scopeConfig->getValue('mongo/general/mongo_general_database')
            );

            $this->mongo->ensureIndex(["metacode", "metadata.code"], "configs");
        } catch (Exception $e) {
            echo $e->getMessage();
        }
    }

    public function getConfig($value)
    {
        $isDefault = $value === 'default';

        $store_code = $isDefault ? 'default' : $value->getData('code');

        $config = $isDefault ? $this->scopeConfig->getValue("") : $this->scopeConfig->getValue("", ScopeInterface::SCOPE_STORE, $store_code);

        $store_data = new stdClass();
        $store_data->metacode = $isDefault ? "default" : "store";
        $store_data->_id = $isDefault ? "default_config" : "country_" . (string)$store_code;

        $metadata = new stdClass();
        $metadata->id = $isDefault ? 'default' : (int)$value->getId();
        $metadata->name = $isDefault ? 'default' : $value->getName();
        $metadata->code = $isDefault ? 'default' : $value->getCode();
        $metadata->isoCode = $isDefault ? 'default' : $value->getCode();
        $metadata->marketplace_id = $isDefault ? 'default' : (int)$value->getWebsite()->getId();
        $metadata->marketplace = $isDefault ? 'default' : $value->getWebsite()->getCode();

        $metadata->base_url = ((int)$config["web"]["secure"]["use_in_frontend"]) ? $config["web"]["secure"]["base_url"] : $config["web"]["unsecure"]["base_url"];

        $metadata->locale = (object)$config['general']["locale"];
        $metadata->locale->name = $metadata->locale->code;

        $currency = new stdClass();
        $currency->code = $config["currency"]["options"]["default"];
        $metadata->currencies[] = $currency;

        $metadata->configs = new stdClass();
        $metadata->configs->default_currency = $config["currency"]["options"]["default"];
        $metadata->configs->store_information = array_key_exists("store_information", $config["general"]) ? (object)$config["general"]["store_information"] : '';
        $metadata->configs->billing_countries = isset($config["general"]["country"]["allow"]) ? explode(",", $config["general"]["country"]["allow"]) : [];
        $metadata->configs->shipping_countries = isset($config["refilo_geoip"]["country"]["allow_shipping"]) ? explode(",", $config["refilo_geoip"]["country"]["allow_shipping"]) : $metadata->configs->billing_countries;

        if (isset($config["refilo_geoip"]["country_store"]["affected_countries"])) {
            $metadata->configs->navigation_countries = explode(",", $config["refilo_geoip"]["country_store"]["affected_countries"]);
        }

        $metadata->configs->europe_countries = explode(",", $config["general"]["country"]["eu_countries"]);
        $metadata->configs->default_country = $config["general"]["country"]["default"];

        $metadata->storefrontConfig = new stdClass();
        //Process Storefront General
        $metadata->storefrontConfig->general = new stdClass();
        $metadata->storefrontConfig->general->site_name = isset($config['design']['head']['default_title']) ? $config['design']['head']['default_title'] : "";
        $metadata->storefrontConfig->general->copyright = isset($config['design']['footer']['copyright']) ? $config['design']['footer']['copyright'] : "";
        $metadata->storefrontConfig->general->top_strip = isset($config["refilo_general"]["discalimers_topbar"]["top_strip"]) ? $config["refilo_general"]["discalimers_topbar"]["top_strip"] : "";

        $metadata->storefrontConfig->general->disclaimers = new stdClass();
        $metadata->storefrontConfig->general->disclaimers->terms_and_conditions = isset($config["refilo_general"]["discalimers_topbar"]["terms_conditions"]) ? $config["refilo_general"]["discalimers_topbar"]["terms_conditions"] : "";
        $metadata->storefrontConfig->general->disclaimers->marketing = isset($config["refilo_general"]["discalimers_topbar"]["marketing_disclaimer"]) ? $config["refilo_general"]["discalimers_topbar"]["marketing_disclaimer"] : "";
        $metadata->storefrontConfig->general->disclaimers->profiling = isset($config["refilo_general"]["discalimers_topbar"]["profiling_disclaimer"]) ? $config["refilo_general"]["discalimers_topbar"]["profiling_disclaimer"] : "";
        $metadata->storefrontConfig->general->disclaimers->privacy_policy = isset($config["refilo_general"]["discalimers_topbar"]["privacy_disclaimer"]) ? $config["refilo_general"]["discalimers_topbar"]["privacy_disclaimer"] : "";
        $metadata->storefrontConfig->general->disclaimers->cookie_policy = isset($config["refilo_general"]["discalimers_topbar"]["cookie_disclaimer"]) ? $config["refilo_general"]["discalimers_topbar"]["cookie_disclaimer"] : "";

        $metadata->storefrontConfig->general->disclaimers->address = new stdClass();
        $metadata->storefrontConfig->general->disclaimers->address->street_additional_label = isset($config["refilo_general"]["discalimers_addresses"]["street_additional_label"]) ? $config["refilo_general"]["discalimers_addresses"]["street_additional_label"] : "";
        $metadata->storefrontConfig->general->disclaimers->address->company_additional_label = isset($config["refilo_general"]["discalimers_addresses"]["company_additional_label"]) ? $config["refilo_general"]["discalimers_addresses"]["company_additional_label"] : "";

        $metadata->storefrontConfig->general->disclaimers->checkout = new stdClass();
        $metadata->storefrontConfig->general->disclaimers->checkout->rassurance_info = isset($config["refilo_general"]["discalimers_checkout"]["rassurance_info"]) ? $config["refilo_general"]["discalimers_checkout"]["rassurance_info"] : "";
        $metadata->storefrontConfig->general->disclaimers->checkout->custom_duties_disclaimer = isset($config["refilo_general"]["discalimers_checkout"]["custom_duties_disclaimer"]) ? $config["refilo_general"]["discalimers_checkout"]["custom_duties_disclaimer"] : "";

        $metadata->storefrontConfig->general->disclaimers->contacts_form = isset($config["refilo_general"]["discalimers_contacts"]["contacts_form"]) ? $config["refilo_general"]["discalimers_contacts"]["contacts_form"] : "";
        $metadata->storefrontConfig->general->disclaimers->work_with_us_form = isset($config["refilo_general"]["discalimers_contacts"]["work_with_us_form"]) ? $config["refilo_general"]["discalimers_contacts"]["work_with_us_form"] : "";

        $metadata->storefrontConfig->general->address_autocomplete = new stdClass();
        $metadata->storefrontConfig->general->address_autocomplete->enabled = isset($config["refilo_general"]["address_autocomplete"]["enable_address_autocomplete"]) ? boolval($config["refilo_general"]["address_autocomplete"]["enable_address_autocomplete"]) : true;
        $metadata->storefrontConfig->general->address_autocomplete->api_key = isset($config["refilo_general"]["address_autocomplete"]["autocomplete_api_key"]) ? $config["refilo_general"]["address_autocomplete"]["autocomplete_api_key"] : "";

        $metadata->storefrontConfig->general->locale = (object)$config['general']["locale"];
        $metadata->storefrontConfig->general->locale->name = $metadata->storefrontConfig->general->locale->code;
        $metadata->storefrontConfig->general->marketplace = $isDefault ? 'default' : $value->getWebsite()->getCode();
        $metadata->storefrontConfig->general->default_currency = $config["currency"]["options"]["default"];
        $metadata->storefrontConfig->general->default_country = $config["general"]["country"]["default"];
        $metadata->storefrontConfig->general->media_base_url = ((int)$config["web"]["secure"]["use_in_frontend"]) ? @$config["web"]["secure"]["base_media_url"] : @$config["web"]["unsecure"]["base_media_url"];
        $metadata->storefrontConfig->general->all_countries = isset($config["general"]["country"]["allow"]) ? explode(",", $config["general"]["country"]["allow"]) : [];
        $metadata->storefrontConfig->general->shipping_countries = isset($config["refilo_geoip"]["country"]["allow_shipping"]) ? explode(",", $config["refilo_geoip"]["country"]["allow_shipping"]) : $metadata->storefrontConfig->general->all_countries;
        if (isset($config["refilo_geoip"]["country"]["enabled_different_shipping_country"]) && boolval($config["refilo_geoip"]["country"]["enabled_different_shipping_country"]) === false) {
            $metadata->storefrontConfig->general->shipping_countries = $metadata->storefrontConfig->general->all_countries;
        }

        //Process Storefront Geoip
        $metadata->storefrontConfig->geoip = new stdClass();
        $metadata->storefrontConfig->geoip->enabled = isset($config["refilo_geoip"]["geoip_config"]["geoip_enabled"]) ? boolval($config["refilo_geoip"]["geoip_config"]["geoip_enabled"]) : true;
        $metadata->storefrontConfig->geoip->popup = isset($config["refilo_geoip"]["geoip_config"]["enable_popup"]) ? boolval($config["refilo_geoip"]["geoip_config"]["enable_popup"]) : true;
        $metadata->storefrontConfig->geoip->geoinfo_cookie_name = isset($config["refilo_geoip"]["geoip_config"]["geoip_cookie_name"]) ? $config["refilo_geoip"]["geoip_config"]["geoip_cookie_name"] : "";
        $metadata->storefrontConfig->geoip->geoinfo_cookie_age = isset($config["refilo_geoip"]["geoip_config"]["geoip_cookie_age"]) ? (int)$config["refilo_geoip"]["geoip_config"]["geoip_cookie_age"] : 86400000;
        $metadata->storefrontConfig->geoip->misfits = isset($config["refilo_geoip"]["geoip_config"]["misfits"]) ? boolval($config["refilo_geoip"]["geoip_config"]["misfits"]) : true;
        $metadata->storefrontConfig->geoip->misfits_cookie_name = isset($config["refilo_geoip"]["geoip_config"]["misfits_cookie_name"]) ? $config["refilo_geoip"]["geoip_config"]["misfits_cookie_name"] : "";
        $metadata->storefrontConfig->geoip->misfits_cookie_age = isset($config["refilo_geoip"]["geoip_config"]["misfits_cookie_age"]) ? (int)$config["refilo_geoip"]["geoip_config"]["misfits_cookie_age"] : 2592000;
        //Process StoreFront Search
        $metadata->storefrontConfig->search = new stdClass();
        $metadata->storefrontConfig->search->recommendations = isset($config['catalog']['search']['search_recommendations_enabled']) ? boolval($config['catalog']['search']['search_recommendations_enabled']) : true;
        $metadata->storefrontConfig->search->recommendations_limit = isset($config['catalog']['search']['search_recommendations_count']) ? (int)$config['catalog']['search']['search_recommendations_count'] : 5;
        $metadata->storefrontConfig->search->suggestions = isset($config['catalog']['search']['search_suggestion_enabled']) ? boolval($config['catalog']['search']['search_suggestion_enabled']) : true;
        $metadata->storefrontConfig->search->suggestions_limit = isset($config['catalog']['search']['search_suggestion_count']) ? (int)$config['catalog']['search']['search_suggestion_count'] : 5;
        //Process StoreFront Notifications
        $metadata->storefrontConfig->notification = new stdClass();
        $metadata->storefrontConfig->notification->enabled = isset($config['refilo_notifications']['general']['enable_notifications']) ? boolval($config['refilo_notifications']['general']['enable_notifications']) : false;
        //Process StoreFront GTagManager
        $metadata->storefrontConfig->google_tag_manager = new stdClass();
        $metadata->storefrontConfig->google_tag_manager->enabled = isset($config['refilo_marketing']['google_tagmanager']['enabled']) ? boolval($config['refilo_marketing']['google_tagmanager']['enabled']) : false;
        $metadata->storefrontConfig->google_tag_manager->code = isset($config['refilo_marketing']['google_tagmanager']['code']) ? $config['refilo_marketing']['google_tagmanager']['code'] : "";
        //Process StoreFront StoreLocator
        $metadata->storefrontConfig->storelocator = new stdClass();
        $metadata->storefrontConfig->storelocator->enabled = isset($config['filoblu_storelocator_section']['general']['enabled']) ? boolval($config['filoblu_storelocator_section']['general']['enabled']) : true;
        $metadata->storefrontConfig->storelocator->key = isset($config['filoblu_storelocator_section']['general']['gmaps_api_key']) ? $config['filoblu_storelocator_section']['general']['gmaps_api_key'] : "";
        $metadata->storefrontConfig->storelocator->details = new stdClass();
        $metadata->storefrontConfig->storelocator->details->enabled = isset($config['filoblu_storelocator_section']['general']['shop_details']) ? boolval($config['filoblu_storelocator_section']['general']['shop_details']) : false;
        $metadata->storefrontConfig->storelocator->autocomplete = new stdClass();
        $metadata->storefrontConfig->storelocator->autocomplete->enabled = isset($config['filoblu_storelocator_section']['search']['gmaps_search_autocomplete_enabled']) ? boolval($config['filoblu_storelocator_section']['search']['gmaps_search_autocomplete_enabled']) : "";
        $metadata->storefrontConfig->storelocator->autocomplete->type = isset($config['filoblu_storelocator_section']['search']['gmaps_search_autocomplete_type']) ? $config['filoblu_storelocator_section']['search']['gmaps_search_autocomplete_type'] : "";
        $metadata->storefrontConfig->storelocator->autocomplete->zoom = isset($config['filoblu_storelocator_section']['search']['gmaps_search_autocomplete_zoom']) ? (int)$config['filoblu_storelocator_section']['search']['gmaps_search_autocomplete_zoom'] : 11;
        $metadata->storefrontConfig->storelocator->tags = new stdClass();
        $metadata->storefrontConfig->storelocator->tags->enabled = isset($config['filoblu_storelocator_section']['search']['gmaps_search_tag_enabled']) ? boolval($config['filoblu_storelocator_section']['search']['gmaps_search_tag_enabled']) : true;
        $metadata->storefrontConfig->storelocator->map = new stdClass();
        $metadata->storefrontConfig->storelocator->map->default_center = isset($config['filoblu_storelocator_section']['map_options']['gmaps_default_center']) ? $config['filoblu_storelocator_section']['map_options']['gmaps_default_center'] : [];
        $metadata->storefrontConfig->storelocator->map->default_zoom = isset($config['filoblu_storelocator_section']['map_options']['gmaps_default_zoom']) ? (int)$config['filoblu_storelocator_section']['map_options']['gmaps_default_zoom'] : 5;
        $metadata->storefrontConfig->storelocator->map->min_zoom = isset($config['filoblu_storelocator_section']['map_options']['gmaps_min_zoom']) ? (int)$config['filoblu_storelocator_section']['map_options']['gmaps_min_zoom'] : 20;
        $metadata->storefrontConfig->storelocator->map->max_zoom = isset($config['filoblu_storelocator_section']['map_options']['gmaps_max_zoom']) ? (int)$config['filoblu_storelocator_section']['map_options']['gmaps_max_zoom'] : 20;
        $metadata->storefrontConfig->storelocator->map->type = isset($config['filoblu_storelocator_section']['map_options']['gmaps_type']) ? $config['filoblu_storelocator_section']['map_options']['gmaps_type'] : "";
        $metadata->storefrontConfig->storelocator->map->style = isset($config['filoblu_storelocator_section']['map_options']['gmaps_style']) ? $config['filoblu_storelocator_section']['map_options']['gmaps_style'] : [];
        $metadata->storefrontConfig->storelocator->map->controls = new stdClass();
        $metadata->storefrontConfig->storelocator->map->controls->zoom = isset($config['filoblu_storelocator_section']['map_options']['gmaps_ui_zoomControl_enabled']) ? boolval($config['filoblu_storelocator_section']['map_options']['gmaps_ui_zoomControl_enabled']) : true;
        $metadata->storefrontConfig->storelocator->map->controls->map_type = isset($config['filoblu_storelocator_section']['map_options']['gmaps_ui_mapTypeControl_enabled']) ? boolval($config['filoblu_storelocator_section']['map_options']['gmaps_ui_mapTypeControl_enabled']) : true;
        $metadata->storefrontConfig->storelocator->map->controls->street_view = isset($config['filoblu_storelocator_section']['map_options']['gmaps_ui_streetViewControl_enabled']) ? boolval($config['filoblu_storelocator_section']['map_options']['gmaps_ui_streetViewControl_enabled']) : true;
        $metadata->storefrontConfig->storelocator->map->controls->rotate = isset($config['filoblu_storelocator_section']['map_options']['gmaps_ui_rotateControl_enabled']) ? boolval($config['filoblu_storelocator_section']['map_options']['gmaps_ui_rotateControl_enabled']) : true;
        $metadata->storefrontConfig->storelocator->map->controls->scale = isset($config['filoblu_storelocator_section']['map_options']['gmaps_ui_scaleControl_enabled']) ? boolval($config['filoblu_storelocator_section']['map_options']['gmaps_ui_scaleControl_enabled']) : true;
        $metadata->storefrontConfig->storelocator->map->controls->fullscreen = isset($config['filoblu_storelocator_section']['map_options']['gmaps_ui_fullscreenControl_enabled']) ? boolval($config['filoblu_storelocator_section']['map_options']['gmaps_ui_fullscreenControl_enabled']) : true;
        $metadata->storefrontConfig->storelocator->geolocation = new stdClass();
        $metadata->storefrontConfig->storelocator->geolocation->enabled = isset($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_enabled']) ? boolval($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_enabled']) : true;
        $metadata->storefrontConfig->storelocator->geolocation->zoom = isset($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_zoom']) ? (int)$config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_zoom'] : 12;
        $metadata->storefrontConfig->storelocator->geolocation->distance = isset($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_distance']) ? boolval($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_distance']) : true;
        $metadata->storefrontConfig->storelocator->geolocation->duration = isset($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_duration']) ? boolval($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_duration']) : true;
        $metadata->storefrontConfig->storelocator->geolocation->directions = isset($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_direction']) ? boolval($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_direction']) : true;
        $metadata->storefrontConfig->storelocator->geolocation->travel_mode = isset($config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_travelmode']) ? $config['filoblu_storelocator_section']['geolocation']['gmaps_geolocation_travelmode'] : "";
        $metadata->storefrontConfig->storelocator->marker = new stdClass();
        $metadata->storefrontConfig->storelocator->marker->image = isset($config['filoblu_storelocator_section']['markers']['gmaps_markers_marker_image']) ? $config['filoblu_storelocator_section']['markers']['gmaps_markers_marker_image'] : "";
        //Process StoreFront NewsletterPopup
        $metadata->storefrontConfig->newsletter_popup = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->enabled = isset($config['newsletter_popup']['general']['enable_popup']) ? boolval($config['newsletter_popup']['general']['enable_popup']) : true;
        $metadata->storefrontConfig->newsletter_popup->auto_open = isset($config['newsletter_popup']['general']['enable_auto_open']) ? boolval($config['newsletter_popup']['general']['enable_auto_open']) : true;
        $metadata->storefrontConfig->newsletter_popup->close_timeout = isset($config['newsletter_popup']['general']['close_timeout']) ? (int)$config['newsletter_popup']['general']['close_timeout'] : 3000;
        $metadata->storefrontConfig->newsletter_popup->open_timeout = isset($config['newsletter_popup']['general']['open_timeout']) ? (int)$config['newsletter_popup']['general']['open_timeout'] : 3000;
        $metadata->storefrontConfig->newsletter_popup->cookie_name = isset($config['newsletter_popup']['general']['cookie_name']) ? $config['newsletter_popup']['general']['cookie_name'] : "";
        $metadata->storefrontConfig->newsletter_popup->cookie_lifetime = isset($config['newsletter_popup']['general']['cookie_lifetime']) ? (int)$config['newsletter_popup']['general']['cookie_lifetime'] : 2592000;
        $metadata->storefrontConfig->newsletter_popup->fields = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->firstname = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->firstname->enabled = isset($config['newsletter_popup']['fields']['firstname_enabled']) ? boolval($config['newsletter_popup']['fields']['firstname_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->firstname->required = isset($config['newsletter_popup']['fields']['firstname_required']) ? boolval($config['newsletter_popup']['fields']['firstname_required']) : false;
        $metadata->storefrontConfig->newsletter_popup->fields->lastname = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->lastname->enabled = isset($config['newsletter_popup']['fields']['lastname_enabled']) ? boolval($config['newsletter_popup']['fields']['lastname_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->lastname->required = isset($config['newsletter_popup']['fields']['lastaname_required']) ? boolval($config['newsletter_popup']['fields']['lastaname_required']) : false;
        $metadata->storefrontConfig->newsletter_popup->fields->dob = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->dob->enabled = isset($config['newsletter_popup']['fields']['dob_enabled']) ? boolval($config['newsletter_popup']['fields']['dob_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->dob->required = isset($config['newsletter_popup']['fields']['dob_required']) ? boolval($config['newsletter_popup']['fields']['dob_required']) : false;
        $metadata->storefrontConfig->newsletter_popup->fields->gender = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->gender->enabled = isset($config['newsletter_popup']['fields']['gender_enabled']) ? boolval($config['newsletter_popup']['fields']['gender_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->gender->required = isset($config['newsletter_popup']['fields']['gender_required']) ? boolval($config['newsletter_popup']['fields']['gender_required']) : false;
        $metadata->storefrontConfig->newsletter_popup->fields->gender->list = isset($config['newsletter_popup']['fields']['gender_list']) ? $this->getListConfig($config['newsletter_popup']['fields']['gender_list']) : [];
        $metadata->storefrontConfig->newsletter_popup->fields->country = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->country->enabled = isset($config['newsletter_popup']['fields']['country_enabled']) ? boolval($config['newsletter_popup']['fields']['country_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->country->required = isset($config['newsletter_popup']['fields']['country_required']) ? boolval($config['newsletter_popup']['fields']['country_required']) : false;
        $metadata->storefrontConfig->newsletter_popup->fields->collections = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->collections->enabled = isset($config['newsletter_popup']['fields']['collections_enabled']) ? boolval($config['newsletter_popup']['fields']['collections_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->collections->required = isset($config['newsletter_popup']['fields']['collections_required']) ? boolval($config['newsletter_popup']['fields']['collections_required']) : false;
        $metadata->storefrontConfig->newsletter_popup->fields->collections->list = isset($config['newsletter_popup']['fields']['collections_list']) ? $this->getListConfig($config['newsletter_popup']['fields']['collections_list']) : [];
        $metadata->storefrontConfig->newsletter_popup->fields->phone = new stdClass();
        $metadata->storefrontConfig->newsletter_popup->fields->phone->enabled = isset($config['newsletter_popup']['fields']['phone_enabled']) ? boolval($config['newsletter_popup']['fields']['phone_enabled']) : true;
        $metadata->storefrontConfig->newsletter_popup->fields->phone->required = isset($config['newsletter_popup']['fields']['phone_required']) ? boolval($config['newsletter_popup']['fields']['phone_required']) : false;
        //Process StoreFront Catalog
        $metadata->storefrontConfig->catalog = new stdClass();
        $metadata->storefrontConfig->catalog->url_key_suffix = isset($config['catalog']['seo']['product_url_suffix']) ? $config['catalog']['seo']['product_url_suffix'] : "";
        $metadata->storefrontConfig->catalog->not_seo_friendly_urls = isset($config['refilo_catalog']['general']['no_seo_friendly_urls']) ? $config['refilo_catalog']['general']['no_seo_friendly_urls'] : "";
        $metadata->storefrontConfig->catalog->hide_price = isset($config['refilo_catalog']['general']['hide_price']) ? boolval($config['refilo_catalog']['general']['hide_price']) : false;
        $metadata->storefrontConfig->catalog->disable_shop = isset($config['refilo_catalog']['general']['disable_shop']) ? boolval($config['refilo_catalog']['general']['disable_shop']) : false;
        $metadata->storefrontConfig->catalog->vat_label = isset($config['refilo_catalog']['general']['vat_label']) ? $config['refilo_catalog']['general']['vat_label'] : "";
        $metadata->storefrontConfig->catalog->shipping_returns_info = isset($config['refilo_catalog']['general']['shipping_returns_info']) ? $config['refilo_catalog']['general']['shipping_returns_info'] : "";
        $metadata->storefrontConfig->catalog->customer_care_info = isset($config['refilo_catalog']['general']['customer_care_info']) ? $config['refilo_catalog']['general']['customer_care_info'] : "";
        $metadata->storefrontConfig->catalog->categories = new stdClass();
        $metadata->storefrontConfig->catalog->categories->products_per_page = isset($config['catalog']['frontend']['grid_per_page']) ? (int)$config['catalog']['frontend']['grid_per_page'] : 12;
        $metadata->storefrontConfig->catalog->categories->pagination_param = isset($config['refilo_catalog']['categories']['pagination_param']) ? $config['refilo_catalog']['categories']['pagination_param'] : "";
        $metadata->storefrontConfig->catalog->categories->sort_filter_name = isset($config['refilo_catalog']['categories']['sort_filter_name']) ? $config['refilo_catalog']['categories']['sort_filter_name'] : "";
        $metadata->storefrontConfig->catalog->categories->multiple_filter_divider = isset($config['refilo_catalog']['categories']['multiple_filter_divider']) ? $config['refilo_catalog']['categories']['multiple_filter_divider'] : "";
        $metadata->storefrontConfig->catalog->categories->history_pagination_push = isset($config['refilo_catalog']['categories']['history_pagination_push']) ? boolval($config['refilo_catalog']['categories']['history_pagination_push']) : true;
        $metadata->storefrontConfig->catalog->categories->history_filter_push = isset($config['refilo_catalog']['categories']['history_filter_push']) ? boolval($config['refilo_catalog']['categories']['history_filter_push']) : true;
        $metadata->storefrontConfig->catalog->categories->price_filter_name = isset($config['refilo_catalog']['categories']['price_filter_name']) ? $config['refilo_catalog']['categories']['price_filter_name'] : "";
        $metadata->storefrontConfig->catalog->categories->price_filter_render = isset($config['refilo_catalog']['categories']['price_filter_render']) ? $config['refilo_catalog']['categories']['price_filter_render'] : "";
        $metadata->storefrontConfig->catalog->products = new stdClass();
        $metadata->storefrontConfig->catalog->products->image_size = new stdClass();
        $metadata->storefrontConfig->catalog->products->image_size->width = isset($config['refilo_catalog']['products']['image_size_width']) ? (int)$config['refilo_catalog']['products']['image_size_width'] : 1000;
        $metadata->storefrontConfig->catalog->products->image_size->height = isset($config['refilo_catalog']['products']['image_size_height']) ? (int)$config['refilo_catalog']['products']['image_size_height'] : 1000;
        $metadata->storefrontConfig->catalog->products->use_demo_placeholder = isset($config['refilo_catalog']['products']['use_demo_placeholder']) ? boolval($config['refilo_catalog']['products']['use_demo_placeholder']) : false;
        $metadata->storefrontConfig->catalog->products->rating = isset($config['refilo_catalog']['products']['rating']) ? boolval($config['refilo_catalog']['products']['rating']) : false;
        $metadata->storefrontConfig->catalog->products->options = new stdClass();
        $metadata->storefrontConfig->catalog->products->options->enable_expand = isset($config['refilo_catalog']['products']['enable_expand']) ? boolval($config['refilo_catalog']['products']['enable_expand']) : "";
        $metadata->storefrontConfig->catalog->products->options->expand_limit_options = isset($config['refilo_catalog']['products']['expand_limit_options']) ? (int)$config['refilo_catalog']['products']['expand_limit_options'] : 15;
        $metadata->storefrontConfig->catalog->products->options->visible_height = isset($config['refilo_catalog']['products']['visible_height']) ? $config['refilo_catalog']['products']['visible_height'] : "";
        //Process Social
        $metadata->storefrontConfig->social = new stdClass();
        $metadata->storefrontConfig->social->login = new stdClass();
        $metadata->storefrontConfig->social->login->facebook_app_id = isset($config["refilo_social"]["login"]["facebook_app_id"]) ? $config["refilo_social"]["login"]["facebook_app_id"] : "";
        $metadata->storefrontConfig->social->login->google_client_id = isset($config["refilo_social"]["login"]["google_client_id"]) ? $config["refilo_social"]["login"]["google_client_id"] : "";
        //Process Sales
        $metadata->storefrontConfig->sales = new stdClass();
        $metadata->storefrontConfig->sales->payments = new stdClass();
        $metadata->storefrontConfig->sales->payments->adyen = new stdClass();
        $metadata->storefrontConfig->sales->payments->adyen->api_key = isset($config["refilo_sales"]["adyen"]["api_key"]) ? $config["refilo_sales"]["adyen"]["api_key"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->mode = isset($config["refilo_sales"]["adyen"]["mode"]) ? $config["refilo_sales"]["adyen"]["mode"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->api_standard_test = isset($config["refilo_sales"]["adyen"]["api_standard_test"]) ? $config["refilo_sales"]["adyen"]["api_standard_test"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->api_standard_live = isset($config["refilo_sales"]["adyen"]["api_standard_live"]) ? $config["refilo_sales"]["adyen"]["api_standard_live"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->api_checkout_test = isset($config["refilo_sales"]["adyen"]["api_checkout_test"]) ? $config["refilo_sales"]["adyen"]["api_checkout_test"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->api_checkout_live = isset($config["refilo_sales"]["adyen"]["api_checkout_live"]) ? $config["refilo_sales"]["adyen"]["api_checkout_live"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->js_test = isset($config["refilo_sales"]["adyen"]["js_test"]) ? $config["refilo_sales"]["adyen"]["js_test"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->js_live = isset($config["refilo_sales"]["adyen"]["js_live"]) ? $config["refilo_sales"]["adyen"]["js_live"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->css_test = isset($config["refilo_sales"]["adyen"]["css_test"]) ? $config["refilo_sales"]["adyen"]["css_test"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->css_live = isset($config["refilo_sales"]["adyen"]["css_live"]) ? $config["refilo_sales"]["adyen"]["css_live"] : "";
        $metadata->storefrontConfig->sales->payments->adyen->cc = new stdClass();
        $metadata->storefrontConfig->sales->payments->adyen->cc->enableStoreDetails = isset($config["refilo_sales"]["adyen"]["cc_enableStoreDetails"]) ? boolval($config["refilo_sales"]["adyen"]["cc_enableStoreDetails"]) : true;
        $metadata->storefrontConfig->sales->payments->adyen->cc->hasHolderName = isset($config["refilo_sales"]["adyen"]["cc_hasHolderName"]) ? boolval($config["refilo_sales"]["adyen"]["cc_hasHolderName"]) : true;
        $metadata->storefrontConfig->sales->payments->adyen->cc->holderNameRequired = isset($config["refilo_sales"]["adyen"]["cc_holderNameRequired"]) ? boolval($config["refilo_sales"]["adyen"]["cc_holderNameRequired"]) : true;
        $metadata->storefrontConfig->sales->payments->adyen->cc->brands = isset($config["refilo_sales"]["adyen"]["cc_brands"]) ? $this->getCcBrands($config["refilo_sales"]["adyen"]["cc_brands"]) : "";
        $metadata->storefrontConfig->sales->gift_message = new stdClass();
        $metadata->storefrontConfig->sales->gift_message->enabled = isset($config["refilo_sales"]["gift_message"]["enabled"]) ? boolval($config["refilo_sales"]["gift_message"]["enabled"]) : true;
        $metadata->storefrontConfig->sales->gift_wrap = new stdClass();
        $metadata->storefrontConfig->sales->gift_wrap->enabled = isset($config["refilo_sales"]["gift_wrap"]["enabled"]) ? boolval($config["refilo_sales"]["gift_wrap"]["enabled"]) : true;
        //Process Content
        $metadata->storefrontConfig->content = new stdClass();
        $metadata->storefrontConfig->content->pages = new stdClass();
        $metadata->storefrontConfig->content->pages->not_seo_friendly_urls = isset($config['refilo_content']['general']['not_seo_friendly_urls']) ? $config['refilo_content']['general']['not_seo_friendly_urls'] : "";
        $metadata->storefrontConfig->content->html_head = new stdClass();
        $metadata->storefrontConfig->content->html_head->default_title = isset($config["design"]["head"]["default_title"]) ? $config["design"]["head"]["default_title"] : "";
        $metadata->storefrontConfig->content->html_head->demonotice = isset($config["design"]["head"]["demonotice"]) ? boolval($config["design"]["head"]["demonotice"]) : false;
        $metadata->storefrontConfig->content->html_head->meta_keywords = isset($config["design"]["head"]["default_keywords"]) ? $config["design"]["head"]["default_keywords"] : "";
        $metadata->storefrontConfig->content->html_head->include_script = isset($config["design"]["head"]["includes"]) ? $config["design"]["head"]["includes"] : "";
        $metadata->storefrontConfig->content->html_head->title_prefix = isset($config["design"]["head"]["title_prefix"]) ? $config["design"]["head"]["title_prefix"] : "";
        $metadata->storefrontConfig->content->html_head->title_suffix = isset($config["design"]["head"]["title_suffix"]) ? $config["design"]["head"]["title_suffix"] : "";
        $metadata->storefrontConfig->content->html_head->meta_description = isset($config["design"]["head"]["default_description"]) ? $config["design"]["head"]["default_description"] : "";
        $metadata->storefrontConfig->content->html_head->favicon = isset($config["design"]["head"]["shortcut_icon"]) ? $config["design"]["head"]["shortcut_icon"] : "";
        $metadata->storefrontConfig->content->footer = new stdClass();
        $metadata->storefrontConfig->content->footer->misc_html = isset($config["design"]["footer"]["absolute_footer"]) ? $config["design"]["footer"]["absolute_footer"] : "";
        $metadata->storefrontConfig->content->search_engine_robots = new stdClass();
        $metadata->storefrontConfig->content->search_engine_robots->default_robots = isset($config["design"]["search_engine_robots"]["default_robots"]) ? $config["design"]["search_engine_robots"]["default_robots"] : "";
        $metadata->storefrontConfig->content->search_engine_robots->custom_instructions = isset($config["design"]["search_engine_robots"]["custom_instructions"]) ? $config["design"]["search_engine_robots"]["custom_instructions"] : "";

        $metadata->storefrontConfig->maintenance = new stdClass();
        $metadata->storefrontConfig->maintenance->enabled = isset($config["maintenance_section"]["general"]["enabled"]) ? boolval($config["maintenance_section"]["general"]["enabled"]) : false;
        $metadata->storefrontConfig->maintenance->allowed_urls = isset($config["maintenance_section"]["general"]["allowed_urls"]) ? $config["maintenance_section"]["general"]["allowed_urls"] : "";
        $metadata->storefrontConfig->maintenance->allowed_ips = isset($config["maintenance_section"]["general"]["allowed_ips"]) ? $config["maintenance_section"]["general"]["allowed_ips"] : "";
        $metadata->storefrontConfig->maintenance->page_title = isset($config["maintenance_section"]["general"]["page_title"]) ? $config["maintenance_section"]["general"]["page_title"] : "";
        $metadata->storefrontConfig->maintenance->bg_image = isset($config["maintenance_section"]["general"]["bg_image"]) ? '/filoblu/maintenance/'.$config["maintenance_section"]["general"]["bg_image"] : "";
        $metadata->storefrontConfig->maintenance->bg_image_mobile = isset($config["maintenance_section"]["general"]["bg_image_mobile"]) ? '/filoblu/maintenance/'.$config["maintenance_section"]["general"]["bg_image_mobile"] : "";
        $metadata->storefrontConfig->maintenance->front_text = isset($config["maintenance_section"]["general"]["front_text"]) ? $config["maintenance_section"]["general"]["front_text"] : "";

        $store_data->metadata = $metadata;

        return $store_data;
    }

    /**
     * @param $config
     * @return array
     */
    public function getListConfig($config)
    {
        $convertedConfig = [];
        $unserializedConfig = unserialize($config);
        foreach ($unserializedConfig as $config) {
            $convertedConfig[] = (object)$config;
        }

        return $convertedConfig;
    }

    /**
     * @param $config
     * @return array
     */
    public function getCcBrands($config)
    {
        $convertedConfig = [];
        $unserializedConfig = unserialize($config);
        foreach ($unserializedConfig as $config) {
            $convertedConfig[] = $config["code"];
        }

        return $convertedConfig;
    }
}
