<?php

namespace FiloBlu\Refilo\Remote\Connector;

use FiloBlu\Refilo\Remote\Entity\EntityInterface;
use MongoDB\Driver\BulkWrite;
use MongoDB\Driver\Manager;
use Traversable;

/**
 * Class MongoDB
 * @package FiloBlu\Refilo\Remote\Connector
 */
class MongoDb extends AbstractConnector
{
    /** @var Manager */
    protected $connection;

    /**
     * @var string
     */
    protected $database;

    /**
     * @return mixed|void
     */
    public function disconnect(): ConnectorInterface
    {
        $this->connection = null;
        return $this;
    }

    /**
     * @param Traversable $entities
     * @param string $collection
     * @return mixed|void
     */
    public function create(Traversable $entities, string $collection)
    {
        $this->connect();
        $bulk = new BulkWrite();

        foreach ($entities as $entity) {
            $entity->setData('_id', $entity->getId());
            $bulk->update(['_id' => $entity->getId()], ['$set' => $entity->toArray()], ['multi' => false, 'upsert' => true]);
        }

        $this->connection->executeBulkWrite("{$this->database}.{$collection}", $bulk);
    }

    /**
     * @return mixed|Manager
     */
    public function connect(): ConnectorInterface
    {
        if (!$this->connection) {
            $this->connection = new Manager($this->getUri());
        }

        return $this;
    }

    /**
     * https://tools.ietf.org/html/rfc3986
     * scheme://[username:password@]host1[:port1][,host2[:port2],...[,hostN[:portN]]][/[database][?options]]
     */
    protected function getUri(): string
    {
        $hosts = $this->getConfiguration()->getData(self::CONFIGURATION_HOST_POOL);

        $dsn = null;

        $host = array_shift($hosts);

        $dsn = "{$host['scheme']}://";

        if ($host['username']) {
            $dsn .= "{$host['username']}:{$host['password']}@";
        }

        $dsn .= $host['host'];

        if ($host['port']) {
            $dsn .= ":{$host['port']}";
        }

        $extraHosts = [];
        foreach ($hosts as $host) {
            $extraHosts[] = $host['host'] . ($host['port'] ? ":{$host['port']}" : '');
        }

        $dsn .= implode(',', $extraHosts);

        if (isset($host['path'])) {
            $this->database = $host['path'];
        }

        return $dsn;
    }

    public function delete(array $entity, string $collection)
    {

    }

    /**
     * @param Traversable $entities
     * @param string $collection
     * @return mixed|void
     */
    public function update(\Traversable $entities, string $collection)
    {
        $this->connect();
        $bulk = new BulkWrite();

        foreach ($entities as $entity) {
            $bulk->update(['_id' => $entity->getId()], ['$set' => $entity->toArray()], ['multi' => false, 'upsert' => false]);
        }

        $this->connection->executeBulkWrite($collection, $bulk);
    }
}
